@@ -157,7 +157,7 @@ def check_data(data, name=""):
         raise ValueError("Name given is not valid. Please supply a string.")
     if isinstance(data, dict):
         return data
-    if isinstance(data, str) and (data.endswith(("npy", "npz")) or ObjectId.is_valid(data)):
+    if isinstance(data, str) and (data.endswith(("npy", "npz")) or ObjectId.is_valid(data) or data == ""):
         return data
     elif isinstance(data, Dataset):
         return data
@@ -353,7 +353,11 @@ def make_request(request_type_function, url, data, headers, json, params, **kwar
         response.raise_for_status()
         return response
     except requests.exceptions.RequestException as _:
-        npu_print(f"Error: {response.json()['error']}", level="ERROR")
+        response = response.json()
+        if "error" in response:
+            npu_print(f"Error: {response['error']}", level="ERROR")
+        elif "message" in response:
+            npu_print(f"Error: {response['message']}", level="ERROR")
     exit(1)
 
 
